@@ -56,10 +56,25 @@ if __name__ == "__main__":
                     # =============================================================================
                     #       GENERATION OF DATASET              
                     # =============================================================================
-                    "material_": ["Cu","Si","Ge","GaN"],             ## same key as used in dict_LaueTools
+                    "material_": ["Zr_alpha",
+                                  "ZrO2_mono",
+                                  "ZrO2_tet",
+                                  "ZrO2_cub",
+                                  "Zr_Nb_Fe",
+                                  ],             ## same key as used in dict_LaueTools
                     "prefix" : "",                 ## prefix for the folder to be created for training dataset
-                    "symmetry": ["cubic","cubic","cubic","hexagonal"],           ## crystal symmetry of material_
-                    "SG": [225,230,230,186],                     ## Space group of material_ (None if not known)
+                    "symmetry": ["hexagonal",
+                                 "monoclinic",
+                                 "tetragonal",
+                                 "cubic",
+                                 "hexagonal",
+                                 ],           ## crystal symmetry of material_
+                    "SG": [194,
+                           14,
+                           137,
+                           225,
+                           194,
+                           ],                     ## Space group of material_ (None if not known)
                     # =============================================================================
                     #        Detector parameters (roughly) of the Experimental setup
                     # =============================================================================
@@ -76,17 +91,28 @@ if __name__ == "__main__":
                     "experimental_directory": "",
                     "experimental_prefix": "",
                     "use_simulated_dataset": True,  ## Use simulated dataset (generated at step 3a) incase no experimental data to verify the trained model
-                    "grid_size_x" : 5,            ## Grid X and Y limit to generate the simulated dataset (a rectangular scan region)
-                    "grid_size_y" : 5,  
-                    "UB_tolerance": [0.5,0.5,0.5,0.5],
+                    "grid_size_x" : 25,            ## Grid X and Y limit to generate the simulated dataset (a rectangular scan region)
+                    "grid_size_y" : 25,  
+                    "UB_tolerance": [0.5,
+                                     0.5,
+                                     0.5,
+                                     0.5,
+                                     0.5],
                     "tolerance_strain": [
                                         [0.6,0.55,0.5,0.45,0.4,0.35,0.3,0.25,0.2,0.15],
                                         [0.6,0.55,0.5,0.45,0.4,0.35,0.3,0.25,0.2,0.15],
                                         [0.6,0.55,0.5,0.45,0.4,0.35,0.3,0.25,0.2,0.15],
-                                        [0.6,0.55,0.5,0.45,0.4,0.35,0.3,0.25,0.2,0.15]
+                                        [0.6,0.55,0.5,0.45,0.4,0.35,0.3,0.25,0.2,0.15],
+                                        [0.6,0.55,0.5,0.45,0.4,0.35,0.3,0.25,0.2,0.15],
                                         ],
                     "strain_free_parameters": ["b","c","alpha","beta","gamma"],
-                    "material_ub_limit": [1000,1000,1000,1000]
+                    "material_ub_limit": [1000,
+                                          1000,
+                                          1000,
+                                          1000,
+                                          1000],
+                    
+                    "UB_matrix_detect": 5
                     }
     
     #%% ## Step 2: Get material parameters 
@@ -153,7 +179,7 @@ if __name__ == "__main__":
     bkg_treatment = "A-B"
 
     ## Requirements
-    ubmat = 4 # How many orientation matrix to detect per Laue pattern
+    ubmat = input_params["UB_matrix_detect"] # How many orientation matrix to detect per Laue pattern
     mode_spotCycle = "slow" ## mode of calculation
     use_previous_UBmatrix_name = False ## Try previous indexation solutions to speed up the process
     strain_calculation = True ## Strain refinement is required or not
@@ -360,48 +386,49 @@ if __name__ == "__main__":
                 material_phase_always_present,
                 crystal,
                 strain_free_parameters] for ii in range(count_global)]
-
+    
+    results = new_MP_multimat_function(valu12[0])
     #%% Launch multiprocessing prediction     
-    args = zip(valu12)
-    with multiprocessing.Pool(ncpu) as pool:
-        results = pool.starmap(new_MP_multimat_function, tqdm(args, total=len(valu12)))
+    # args = zip(valu12)
+    # with multiprocessing.Pool(ncpu) as pool:
+    #     results = pool.starmap(new_MP_multimat_function, tqdm(args, total=len(valu12)))
         
-        for r in results:
-            r_message_mpdata = r
-            strain_matrix_mpdata, strain_matrixs_mpdata, rotation_matrix_mpdata, col_mpdata,\
-            colx_mpdata, coly_mpdata, match_rate_mpdata, mat_global_mpdata,\
-                cnt_mpdata, meta_mpdata, files_treated_mpdata, spots_len_mpdata, \
-                    iR_pixel_mpdata, fR_pixel_mpdata, best_match_mpdata, check_mpdata = r_message_mpdata
+    #     for r in results:
+    #         r_message_mpdata = r
+    #         strain_matrix_mpdata, strain_matrixs_mpdata, rotation_matrix_mpdata, col_mpdata,\
+    #         colx_mpdata, coly_mpdata, match_rate_mpdata, mat_global_mpdata,\
+    #             cnt_mpdata, meta_mpdata, files_treated_mpdata, spots_len_mpdata, \
+    #                 iR_pixel_mpdata, fR_pixel_mpdata, best_match_mpdata, check_mpdata = r_message_mpdata
     
-            for i_mpdata in files_treated_mpdata:
-                files_treated.append(i_mpdata)
+    #         for i_mpdata in files_treated_mpdata:
+    #             files_treated.append(i_mpdata)
     
-            for intmat_mpdata in range(int(ubmat)):
-                check[cnt_mpdata,intmat_mpdata] = check_mpdata[cnt_mpdata,intmat_mpdata]
-                mat_global[intmat_mpdata][0][cnt_mpdata] = mat_global_mpdata[intmat_mpdata][0][cnt_mpdata]
-                strain_matrix[intmat_mpdata][0][cnt_mpdata,:,:] = strain_matrix_mpdata[intmat_mpdata][0][cnt_mpdata,:,:]
-                strain_matrixs[intmat_mpdata][0][cnt_mpdata,:,:] = strain_matrixs_mpdata[intmat_mpdata][0][cnt_mpdata,:,:]
-                rotation_matrix[intmat_mpdata][0][cnt_mpdata,:,:] = rotation_matrix_mpdata[intmat_mpdata][0][cnt_mpdata,:,:]
-                col[intmat_mpdata][0][cnt_mpdata,:] = col_mpdata[intmat_mpdata][0][cnt_mpdata,:]
-                colx[intmat_mpdata][0][cnt_mpdata,:] = colx_mpdata[intmat_mpdata][0][cnt_mpdata,:]
-                coly[intmat_mpdata][0][cnt_mpdata,:] = coly_mpdata[intmat_mpdata][0][cnt_mpdata,:]
-                match_rate[intmat_mpdata][0][cnt_mpdata] = match_rate_mpdata[intmat_mpdata][0][cnt_mpdata]
-                spots_len[intmat_mpdata][0][cnt_mpdata] = spots_len_mpdata[intmat_mpdata][0][cnt_mpdata]
-                iR_pix[intmat_mpdata][0][cnt_mpdata] = iR_pixel_mpdata[intmat_mpdata][0][cnt_mpdata]
-                fR_pix[intmat_mpdata][0][cnt_mpdata] = fR_pixel_mpdata[intmat_mpdata][0][cnt_mpdata]
-                best_match[intmat_mpdata][0][cnt_mpdata] = best_match_mpdata[intmat_mpdata][0][cnt_mpdata]
+    #         for intmat_mpdata in range(int(ubmat)):
+    #             check[cnt_mpdata,intmat_mpdata] = check_mpdata[cnt_mpdata,intmat_mpdata]
+    #             mat_global[intmat_mpdata][0][cnt_mpdata] = mat_global_mpdata[intmat_mpdata][0][cnt_mpdata]
+    #             strain_matrix[intmat_mpdata][0][cnt_mpdata,:,:] = strain_matrix_mpdata[intmat_mpdata][0][cnt_mpdata,:,:]
+    #             strain_matrixs[intmat_mpdata][0][cnt_mpdata,:,:] = strain_matrixs_mpdata[intmat_mpdata][0][cnt_mpdata,:,:]
+    #             rotation_matrix[intmat_mpdata][0][cnt_mpdata,:,:] = rotation_matrix_mpdata[intmat_mpdata][0][cnt_mpdata,:,:]
+    #             col[intmat_mpdata][0][cnt_mpdata,:] = col_mpdata[intmat_mpdata][0][cnt_mpdata,:]
+    #             colx[intmat_mpdata][0][cnt_mpdata,:] = colx_mpdata[intmat_mpdata][0][cnt_mpdata,:]
+    #             coly[intmat_mpdata][0][cnt_mpdata,:] = coly_mpdata[intmat_mpdata][0][cnt_mpdata,:]
+    #             match_rate[intmat_mpdata][0][cnt_mpdata] = match_rate_mpdata[intmat_mpdata][0][cnt_mpdata]
+    #             spots_len[intmat_mpdata][0][cnt_mpdata] = spots_len_mpdata[intmat_mpdata][0][cnt_mpdata]
+    #             iR_pix[intmat_mpdata][0][cnt_mpdata] = iR_pixel_mpdata[intmat_mpdata][0][cnt_mpdata]
+    #             fR_pix[intmat_mpdata][0][cnt_mpdata] = fR_pixel_mpdata[intmat_mpdata][0][cnt_mpdata]
+    #             best_match[intmat_mpdata][0][cnt_mpdata] = best_match_mpdata[intmat_mpdata][0][cnt_mpdata]
                 
-    #%% Save results
-    save_directory_ = filenameDirec+"//results_"+prefix_mat+"_"+c_time
-    if not os.path.exists(save_directory_):
-        os.makedirs(save_directory_)
+    # #%% Save results
+    # save_directory_ = filenameDirec+"//results_"+prefix_mat+"_"+c_time
+    # if not os.path.exists(save_directory_):
+    #     os.makedirs(save_directory_)
         
-    ## intermediate saving of pickle objects with results
-    with open(save_directory_+ "//results.pickle", "wb") as output_file:
-            cPickle.dump([best_match, mat_global, rotation_matrix, strain_matrix, 
-                          strain_matrixs, col, colx, coly, match_rate, files_treated,
-                          lim_x, lim_y, spots_len, iR_pix, fR_pix,
-                          material_, lattice_material,
-                          symmetry, crystal], output_file)
-    print("data saved in ", save_directory_)
+    # ## intermediate saving of pickle objects with results
+    # with open(save_directory_+ "//results.pickle", "wb") as output_file:
+    #         cPickle.dump([best_match, mat_global, rotation_matrix, strain_matrix, 
+    #                       strain_matrixs, col, colx, coly, match_rate, files_treated,
+    #                       lim_x, lim_y, spots_len, iR_pix, fR_pix,
+    #                       material_, lattice_material,
+    #                       symmetry, crystal], output_file)
+    # print("data saved in ", save_directory_)
 
